==> openshift-model-6.3.1-sources.jar: io/fabric8/openshift/api/model/PodSecurityPolicySubjectReviewStatusFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.PodTemplateSpecFluentImpl;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.PodTemplateSpec;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodSecurityPolicySubjectReviewStatusFluentImpl<A extends PodSecurityPolicySubjectReviewStatusFluent<A>> extends BaseFluent<A> implements PodSecurityPolicySubjectReviewStatusFluent<A>{
  public PodSecurityPolicySubjectReviewStatusFluentImpl() {
  }
  public PodSecurityPolicySubjectReviewStatusFluentImpl(PodSecurityPolicySubjectReviewStatus instance) {
    this.withAllowedBy(instance.getAllowedBy()); 
    this.withReason(instance.getReason()); 
    this.withTemplate(instance.getTemplate()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ObjectReferenceBuilder allowedBy;
  private String reason;
  private PodTemplateSpecBuilder template;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildAllowedBy instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getAllowedBy() {
    return this.allowedBy!=null ?this.allowedBy.build():null;
  }
  public ObjectReference buildAllowedBy() {
    return this.allowedBy!=null ?this.allowedBy.build():null;
  }
  public A withAllowedBy(ObjectReference allowedBy) {
    _visitables.get("allowedBy").remove(this.allowedBy);
    if (allowedBy!=null){ this.allowedBy= new ObjectReferenceBuilder(allowedBy); _visitables.get("allowedBy").add(this.allowedBy);} else { this.allowedBy = null; _visitables.get("allowedBy").remove(this.allowedBy); } return (A) this;
  }
  public Boolean hasAllowedBy() {
    return this.allowedBy != null;
  }
  public PodSecurityPolicySubjectReviewStatusFluent.AllowedByNested<A> withNewAllowedBy() {
    return new PodSecurityPolicySubjectReviewStatusFluentImpl.AllowedByNestedImpl();
  }
  public PodSecurityPolicySubjectReviewStatusFluent.AllowedByNested<A> withNewAllowedByLike(ObjectReference item) {
    return new PodSecurityPolicySubjectReviewStatusFluentImpl.AllowedByNestedImpl(item);
  }
  public PodSecurityPolicySubjectReviewStatusFluent.AllowedByNested<A> editAllowedBy() {
    return withNewAllowedByLike(getAllowedBy());
  }
  public PodSecurityPolicySubjectReviewStatusFluent.AllowedByNested<A> editOrNewAllowedBy() {
    return withNewAllowedByLike(getAllowedBy() != null ? getAllowedBy(): new ObjectReferenceBuilder().build());
  }
  public PodSecurityPolicySubjectReviewStatusFluent.AllowedByNested<A> editOrNewAllowedByLike(ObjectReference item) {
    return withNewAllowedByLike(getAllowedBy() != null ? getAllowedBy(): item);
  }
  public String getReason() {
    return this.reason;
  }
  public A withReason(String reason) {
    this.reason=reason; return (A) this;
  }
  public Boolean hasReason() {
    return this.reason != null;
  }
  
  /**
   * This method has been deprecated, please use method buildTemplate instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodTemplateSpec getTemplate() {
    return this.template!=null ?this.template.build():null;
  }
  public PodTemplateSpec buildTemplate() {
    return this.template!=null ?this.template.build():null;
  }
  public A withTemplate(PodTemplateSpec template) {
    _visitables.get("template").remove(this.template);
    if (template!=null){ this.template= new PodTemplateSpecBuilder(template); _visitables.get("template").add(this.template);} else { this.template = null; _visitables.get("template").remove(this.template); } return (A) this;
  }
  public Boolean hasTemplate() {
    return this.template != null;
  }
  public PodSecurityPolicySubjectReviewStatusFluent.TemplateNested<A> withNewTemplate() {
    return new PodSecurityPolicySubjectReviewStatusFluentImpl.TemplateNestedImpl();
  }
  public PodSecurityPolicySubjectReviewStatusFluent.TemplateNested<A> withNewTemplateLike(PodTemplateSpec item) {
    return new PodSecurityPolicySubjectReviewStatusFluentImpl.TemplateNestedImpl(item);
  }
  public PodSecurityPolicySubjectReviewStatusFluent.TemplateNested<A> editTemplate() {
    return withNewTemplateLike(getTemplate());
  }
  public PodSecurityPolicySubjectReviewStatusFluent.TemplateNested<A> editOrNewTemplate() {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): new PodTemplateSpecBuilder().build());
  }
  public PodSecurityPolicySubjectReviewStatusFluent.TemplateNested<A> editOrNewTemplateLike(PodTemplateSpec item) {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodSecurityPolicySubjectReviewStatusFluentImpl that = (PodSecurityPolicySubjectReviewStatusFluentImpl) o;
    if (allowedBy != null ? !allowedBy.equals(that.allowedBy) :that.allowedBy != null) return false;
    if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
    if (template != null ? !template.equals(that.template) :that.template != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(allowedBy,  reason,  template,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (allowedBy != null) { sb.append("allowedBy:"); sb.append(allowedBy + ","); }
    if (reason != null) { sb.append("reason:"); sb.append(reason + ","); }
    if (template != null) { sb.append("template:"); sb.append(template + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class AllowedByNestedImpl<N> extends ObjectReferenceFluentImpl<PodSecurityPolicySubjectReviewStatusFluent.AllowedByNested<N>> implements PodSecurityPolicySubjectReviewStatusFluent.AllowedByNested<N>,Nested<N>{
    AllowedByNestedImpl(ObjectReference item) {
      this.builder = new ObjectReferenceBuilder(this, item);
    }
    AllowedByNestedImpl() {
      this.builder = new ObjectReferenceBuilder(this);
    }
    ObjectReferenceBuilder builder;
    public N and() {
      return (N) PodSecurityPolicySubjectReviewStatusFluentImpl.this.withAllowedBy(builder.build());
    }
    public N endAllowedBy() {
      return and();
    }
    
  }
  class TemplateNestedImpl<N> extends PodTemplateSpecFluentImpl<PodSecurityPolicySubjectReviewStatusFluent.TemplateNested<N>> implements PodSecurityPolicySubjectReviewStatusFluent.TemplateNested<N>,Nested<N>{
    TemplateNestedImpl(PodTemplateSpec item) {
      this.builder = new PodTemplateSpecBuilder(this, item);
    }
    TemplateNestedImpl() {
      this.builder = new PodTemplateSpecBuilder(this);
    }
    PodTemplateSpecBuilder builder;
    public N and() {
      return (N) PodSecurityPolicySubjectReviewStatusFluentImpl.this.withTemplate(builder.build());
    }
    public N endTemplate() {
      return and();
    }
    
  }
  
}

==> openshift-model-6.7.1-sources.jar: io/fabric8/openshift/api/model/PodSecurityPolicySubjectReviewStatusFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.PodTemplateSpecFluentImpl;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.PodTemplateSpec;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodSecurityPolicySubjectReviewStatusFluentImpl<A extends PodSecurityPolicySubjectReviewStatusFluent<A>> extends BaseFluent<A> implements PodSecurityPolicySubjectReviewStatusFluent<A>{
  public PodSecurityPolicySubjectReviewStatusFluentImpl() {
  }
  public PodSecurityPolicySubjectReviewStatusFluentImpl(PodSecurityPolicySubjectReviewStatus instance) {
    if (instance != null) {
      this.withAllowedBy(instance.getAllowedBy());
      this.withReason(instance.getReason());
      this.withTemplate(instance.getTemplate());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ObjectReferenceBuilder allowedBy;
  private String reason;
  private PodTemplateSpecBuilder template;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildAllowedBy instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getAllowedBy() {
    return this.allowedBy!=null ?this.allowedBy.build():null;
  }
  public ObjectReference buildAllowedBy() {
    return this.allowedBy!=null ?this.allowedBy.build():null;
  }
  public A withAllowedBy(ObjectReference allowedBy) {
    _visitables.get("allowedBy").remove(this.allowedBy);
    if (allowedBy!=null){ this.allowedBy= new ObjectReferenceBuilder(allowedBy); _visitables.get("allowedBy").add(this.allowedBy);} else { this.allowedBy = null; _visitables.get("allowedBy").remove(this.allowedBy); } return (A) this;
  }
  public Boolean hasAllowedBy() {
    return this.allowedBy != null;
  }
  public PodSecurityPolicySubjectReviewStatusFluentImpl.AllowedByNested<A> withNewAllowedBy() {
    return new PodSecurityPolicySubjectReviewStatusFluentImpl.AllowedByNestedImpl();
  }
  public PodSecurityPolicySubjectReviewStatusFluentImpl.AllowedByNested<A> withNewAllowedByLike(ObjectReference item) {
    return new PodSecurityPolicySubjectReviewStatusFluentImpl.AllowedByNestedImpl(item);
  }
  public PodSecurityPolicySubjectReviewStatusFluentImpl.AllowedByNested<A> editAllowedBy() {
    return withNewAllowedByLike(getAllowedBy());
  }
  public PodSecurityPolicySubjectReviewStatusFluentImpl.AllowedByNested<A> editOrNewAllowedBy() {
    return withNewAllowedByLike(getAllowedBy() != null ? getAllowedBy(): new ObjectReferenceBuilder().build());
  }
  public PodSecurityPolicySubjectReviewStatusFluentImpl.AllowedByNested<A> editOrNewAllowedByLike(ObjectReference item) {
    return withNewAllowedByLike(getAllowedBy() != null ? getAllowedBy(): item);
  }
  public String getReason() {
    return this.reason;
  }
  public A withReason(String reason) {
    this.reason=reason; return (A) this;
  }
  public Boolean hasReason() {
    return this.reason != null;
  }
  
  /**
   * This method has been deprecated, please use method buildTemplate instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodTemplateSpec getTemplate() {
    return this.template!=null ?this.template.build():null;
  }
  public PodTemplateSpec buildTemplate() {
    return this.template!=null ?this.template.build():null;
  }
  public A withTemplate(PodTemplateSpec template) {
    _visitables.get("template").remove(this.template);
    if (template!=null){ this.template= new PodTemplateSpecBuilder(template); _visitables.get("template").add(this.template);} else { this.template = null; _visitables.get("template").remove(this.template); } return (A) this;
  }
  public Boolean hasTemplate() {
    return this.template != null;
  }
  public PodSecurityPolicySubjectReviewStatusFluentImpl.TemplateNested<A> withNewTemplate() {
    return new PodSecurityPolicySubjectReviewStatusFluentImpl.TemplateNestedImpl();
  }
  public PodSecurityPolicySubjectReviewStatusFluentImpl.TemplateNested<A> withNewTemplateLike(PodTemplateSpec item) {
    return new PodSecurityPolicySubjectReviewStatusFluentImpl.TemplateNestedImpl(item);
  }
  public PodSecurityPolicySubjectReviewStatusFluentImpl.TemplateNested<A> editTemplate() {
    return withNewTemplateLike(getTemplate());
  }
  public PodSecurityPolicySubjectReviewStatusFluentImpl.TemplateNested<A> editOrNewTemplate() {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): new PodTemplateSpecBuilder().build());
  }
  public PodSecurityPolicySubjectReviewStatusFluentImpl.TemplateNested<A> editOrNewTemplateLike(PodTemplateSpec item) {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodSecurityPolicySubjectReviewStatusFluentImpl that = (PodSecurityPolicySubjectReviewStatusFluentImpl) o;
    if (!java.util.Objects.equals(allowedBy, that.allowedBy)) return false;

    if (!java.util.Objects.equals(reason, that.reason)) return false;

    if (!java.util.Objects.equals(template, that.template)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(allowedBy,  reason,  template,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (allowedBy != null) { sb.append("allowedBy:"); sb.append(allowedBy + ","); }
    if (reason != null) { sb.append("reason:"); sb.append(reason + ","); }
    if (template != null) { sb.append("template:"); sb.append(template + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class AllowedByNestedImpl<N> extends ObjectReferenceFluentImpl<PodSecurityPolicySubjectReviewStatusFluentImpl.AllowedByNested<N>> implements PodSecurityPolicySubjectReviewStatusFluentImpl.AllowedByNested<N>,Nested<N>{
    AllowedByNestedImpl(ObjectReference item) {
      this.builder = new ObjectReferenceBuilder(this, item);
    }
    AllowedByNestedImpl() {
      this.builder = new ObjectReferenceBuilder(this);
    }
    ObjectReferenceBuilder builder;
    public N and() {
      return (N) PodSecurityPolicySubjectReviewStatusFluentImpl.this.withAllowedBy(builder.build());
    }
    public N endAllowedBy() {
      return and();
    }
    
  }
  class TemplateNestedImpl<N> extends PodTemplateSpecFluentImpl<PodSecurityPolicySubjectReviewStatusFluentImpl.TemplateNested<N>> implements PodSecurityPolicySubjectReviewStatusFluentImpl.TemplateNested<N>,Nested<N>{
    TemplateNestedImpl(PodTemplateSpec item) {
      this.builder = new PodTemplateSpecBuilder(this, item);
    }
    TemplateNestedImpl() {
      this.builder = new PodTemplateSpecBuilder(this);
    }
    PodTemplateSpecBuilder builder;
    public N and() {
      return (N) PodSecurityPolicySubjectReviewStatusFluentImpl.this.withTemplate(builder.build());
    }
    public N endTemplate() {
      return and();
    }
    
  }
  
}
